@@ -1,6 +1,6 @@
 #' Partial Derivative dy/d[wrt]
 #'
-#' Returns the numerical partial derivate of y with respect to [wrt] any regressor for a point of interest.  Finite difference method is used with \link{NNS.reg} estimates as f(x+h) and f(x-h) values.
+#' Returns the numerical partial derivate of \code{y} with respect to [wrt] any regressor for a point of interest.  Finite difference method is used with \link{NNS.reg} estimates as \code{f(x+h)} and \code{f(x-h)} values.
 #'
 #' @param x a numeric matrix or data frame.
 #' @param y a numeric vector with compatible dimsensions to \code{x}.
@@ -12,7 +12,6 @@
 #' @param n.best integer; Sets the number of closest regression points to use in weighting.  Defaults to 2.
 #' @param mixed logical; \code{FALSE} (default) If mixed derivative is to be evaluated, set \code{(mixed=TRUE)}.
 #' @param plot logical; \code{FALSE} (default) Set to \code{(plot=TRUE)} to view plot.
-#' @param norm \code{NULL} (default) the method of normalization options: ("NNS","std"); Normalizes \code{x} between 0 and 1 for multivariate regression when set to \code{(norm="std")}, or normalizes \code{x} according to \link{NNS.norm} when set to \code{(norm="NNS")}.
 #' @param noise.reduction the method of determing regression points options: ("mean","median","mode","off"); In low signal to noise situations, \code{noise.reduction="median"} uses medians instead of means for partitions, while \code{noise.reduction="mode"} uses modes instead of means for partitions.  \code{noise.reduction="off"}  allows for maximum possible fit in \link{NNS.reg}. Default setting is \code{noise.reduction="mean"}.
 #' @return Returns the 1st derivative \code{"First Derivative"}, 2nd derivative \code{"Second Derivative"}, and mixed derivative \code{"Mixed Derivative"} (for two independent variables only).
 #' @note For known function testing and analysis, regressors should be transformed via \link{expand.grid} to fill the dimensions with \code{(order="max")}.  Example provided below.
@@ -33,7 +32,7 @@
 #' @export
 
 
-dy.d_<- function(x,y,wrt,eval.points="median",order=NULL,stn=0.9,h=.1,n.best=2,mixed=FALSE,plot=FALSE,norm=NULL,noise.reduction='mean'){
+dy.d_<- function(x,y,wrt,eval.points="median",order=NULL,stn=0.9,h=.1,n.best=2,mixed=FALSE,plot=FALSE,noise.reduction='mean'){
   if(eval.points[1]=="median"){
     eval.points=numeric()
     eval.points=apply(x,2,median)}
@@ -50,7 +49,7 @@ dy.d_<- function(x,y,wrt,eval.points="median",order=NULL,stn=0.9,h=.1,n.best=2,m
   deriv.points = matrix(c(original.eval.points.min,eval.points,original.eval.points.max),ncol=length(eval.points),byrow = TRUE)
 
 
-  estimates = NNS.reg(x,y,order=order,point.est = deriv.points,n.best=n.best,stn = stn,plot=plot,norm=norm,noise.reduction=noise.reduction)$Point.est
+  estimates = NNS.reg(x,y,order=order,point.est = deriv.points,n.best=n.best,stn = stn,plot=plot,noise.reduction=noise.reduction)$Point.est
 
 
   lower=estimates[1]
